#ifndef _SJOG_LIST_H
#define _SJOG_LIST_H 1

#include "sjog.h"

/* -------------------------------------------------------------------------- */

void sjog_list_init();
void sjog_list_set_list();
void sjog_list_show();
void sjog_list_hide();
void sjog_list_check_jog_position(int jog);
void sjog_list_exec_cmd();
void sjog_list_select_next();
void sjog_list_select_previous();
void sjog_list_go_back();
void sjog_list_reset_timer();

#endif
